##
##  pkgconfig.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2020 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         pkgconfig
Summary:      Package Configuration Tool
URL:          http://pkgconfig.freedesktop.org/
Vendor:       Free Desktop Project
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Building
License:      GPL
Version:      0.27.1
Release:      20200104

#   list of sources
Source0:      http://pkgconfig.freedesktop.org/releases/pkg-config-%{version}.tar.gz
Patch0:       pkgconfig.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  gettext, libiconv
PreReq:       gettext, libiconv

%description
    pkg-config is a system for managing library compile/link flags
    that works with automake and autoconf. It replaces the ubiquitous
    xxx-config scripts you may have seen with a single tool.

%track
    prog pkgconfig = {
        version   = %{version}
        url       = http://pkgconfig.freedesktop.org/releases/
        regex     = pkg-config-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n pkg-config-%{version}
    %patch -p0
    %{l_shtool} subst \
        -e '/LINENO: error: C[+]* preprocessor/{N;N;N;N;s/.*/:/;}' \
        -e 's;-Wall;;' \
        configure glib/configure

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    GLIB_CFLAGS="%{l_cppflags glib .} -I%{l_prefix}/lib/glib/include" \
    GLIB_LIBS="%{l_ldflags} -lintl -liconv" \
    GREP="grep" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --enable-indirect-deps=yes \
        --with-internal-glib \
        --with-libiconv=gnu \
        --disable-nls \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    %{l_shtool} mkdir -f -p -m 755 $RPM_BUILD_ROOT%{l_prefix}/lib/pkgconfig
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/doc >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std}

%files -f files

%clean

